---
name: Bug/problem report
about: Describe the issue so that we can help you/fix it
title: ''
labels: bug, question
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**System:**
Please give information on your operating system and python and module versions you are using. 
You can go in napari in `Help>napari info` and copy-paste the first paragraph here that list the operating system and module versions.


**Additional context**
Add any other context about the problem here.
